# Table of Contents

- [meta-model-configuration](<./meta-model-configuration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Meta Model Configuration](<./Meta-Model-Configuration.md>)
  - [Overview](<./Meta-Model-Configuration/Overview.md>)
  - [Best Practices](<./Meta-Model-Configuration/Best-Practices.md>)
  - [Configuring a Fact Sheet](<./Meta-Model-Configuration/Configuring-a-Fact-Sheet.md>)
  - [Fact Sheet Settings](<./Meta-Model-Configuration/Fact-Sheet-Settings.md>)
  - [Fact Sheet Description](<./Meta-Model-Configuration/Fact-Sheet-Description.md>)
  - [Fact Sheet Structure](<./Meta-Model-Configuration/Fact-Sheet-Structure.md>)
  - [Adding Sections and Subsections](<./Meta-Model-Configuration/Adding-Sections-and-Subsections.md>)
  - [Reordering Sections and Subsections](<./Meta-Model-Configuration/Reordering-Sections-and-Subsections.md>)
  - [Hiding Sections and Subsections](<./Meta-Model-Configuration/Hiding-Sections-and-Subsections.md>)
  - [Fact Sheet Attributes](<./Meta-Model-Configuration/Fact-Sheet-Attributes.md>)
  - [Adding Custom Attributes](<./Meta-Model-Configuration/Adding-Custom-Attributes.md>)
  - [Attribute Key](<./Meta-Model-Configuration/Attribute-Key.md>)
  - [Unused Fields and Relations](<./Meta-Model-Configuration/Unused-Fields-and-Relations.md>)
  - [Translations](<./Meta-Model-Configuration/Translations.md>)
  - [Configuration Changelog](<./Meta-Model-Configuration/Configuration-Changelog.md>)
  - [Notifications of Configuration Changes](<./Meta-Model-Configuration/Notifications-of-Configuration-Changes.md>)
